--[[
    .bash_login will be the handler for shutting down after love terminates
    usbmount package will automatically mount and umount USBs

]]

local colormap = {
    white = {240,240,240},
    orange = {242,178,51},
    magenta = {229,127,216},
    lightBlue = {153,178,242},
    yellow = {222,222,108},
    lime = {127,204,25},
    pink = {242,178,204},
    gray = {76,76,76},
    lightGray = {153,153,153},
    cyan = {76,153,178},
    purple = {178,102,229},
    blue = {51,102,204},
    brown = {127,102,76},
    green = {87,166,78},
    red = {204,76,76},
    black = {25,25,25},
}

realscreenwidth = love.graphics.getWidth()
realscreenheight = love.graphics.getHeight()
fakescreenwidth = math.floor((realscreenwidth/12))-1
fakescreenheight = math.floor((realscreenheight/18))-1
startx = math.floor((realscreenwidth-(fakescreenwidth*12))/2)
starty = math.floor((realscreenheight-(fakescreenheight*18))/2)

print('realscreenwidth: '..realscreenwidth)
print('realscreenheight: '..realscreenheight)
print('fakescreenwidth: '..fakescreenwidth)
print('fakescreenheight: '..fakescreenheight)
print('startx: '..startx)
print('starty: '..starty)

function calculateDay()
    return os.date('*t').yday
end

function calculateGameTicks()
    local hours = math.floor(((os.time()%86400)/3600))
    local minutes = math.floor((os.time()%3600)/60)
    local seconds = math.floor(os.time()%60)
    local time = (seconds+(minutes*60)+(hours*3600))
    return math.floor(((time)*0.02)%24*1000)/1000
end
print("os.day(): "..calculateDay())
print("os.time(): "..calculateGameTicks())
print('Fullscreen mode: Desktop')
-- One screen tile/pixel = 12x18 real pixels
function love.load(arg)
    love.mouse.setVisible(false)
    love.mouse.setGrabbed(true)
    cursorimg = love.graphics.newImage('assets/cursor.png')
    cursorimg:setFilter('nearest','nearest')
    --[[cursor = love.mouse.newCursor(cursorimg:getData())
    love.mouse.setCursor(cursor)
    love.mouse.setVisible(true)]]
end

function drawTile(x,y,color)
    -- TODO add colormap
    x = x-1
    y = y-1
    love.graphics.setColor(color[1],color[2],color[3])
    love.graphics.rectangle('fill',(x*12)+startx,(y*18)+starty,12,18)
end

function love.update(dt)
    if love.keyboard.isDown('escape') then -- Exit on Escape key press
        love.event.push('quit')
    end

    realscreenwidth = love.graphics.getWidth()
    realscreenheight = love.graphics.getHeight()
    fakescreenwidth = math.floor((realscreenwidth/12))-1
    fakescreenheight = math.floor((realscreenheight/18))-1
    startx = math.floor((realscreenwidth-(fakescreenwidth*12))/2)
    starty = math.floor((realscreenheight-(fakescreenheight*18))/2)
end

function love.draw(dt)
    drawTile(1,1,colormap.white)
    drawTile(2,1,colormap.orange)
    drawTile(3,1,colormap.magenta)
    drawTile(4,1,colormap.lightBlue)
    drawTile(5,1,colormap.yellow)
    drawTile(6,1,colormap.lime)
    drawTile(7,1,colormap.pink)
    drawTile(8,1,colormap.gray)
    drawTile(9,1,colormap.lightGray)
    drawTile(10,1,colormap.cyan)
    drawTile(11,1,colormap.purple)
    drawTile(12,1,colormap.blue)
    drawTile(14,1,colormap.green)
    drawTile(13,1,colormap.brown)
    love.graphics.setColor(255,255,255)
    love.graphics.draw(cursorimg,love.mouse.getX(),love.mouse.getY())
end
